#ifndef __I_AV_LIVE_CORE_H__
#define __I_AV_LIVE_CORE_H__
#include <string>
#include <windows.h>

#ifdef LIVECORE_EXPORTS
#define API_LIVE_CORE  extern "C" __declspec(dllexport)
#else
#define API_LIVE_CORE  extern "C" __declspec(dllimport)
#endif

struct IAvLiveCoreSink;

struct IAvLiveCore
{
	virtual ~IAvLiveCore() {}
	virtual bool Init(void) = 0;
	virtual bool Advice(IAvLiveCoreSink* pSink) = 0;
	virtual bool UnAdvice(IAvLiveCoreSink* pSink) = 0;
	virtual int  EnableAlgoAEC(bool enable) = 0;

	// push stream (record)
	virtual int StartPushRtmpStream(HWND hWnd, std::string& strUrl) = 0;
	virtual int StopPushRtmpStream(void) = 0;
	virtual bool SetPushStreamMute(bool bMute) = 0;       // mic
	virtual bool UpdatePushVideoRender(HWND hWnd) = 0;    // used when switch push/pull stream hwnd.
	virtual bool SetCodecType(int type) = 0;
	virtual int GetCodecType() = 0;

	// pull stream (play)
	virtual int64_t StartPullRtmpStream(HWND hWnd, std::string& strUrl) = 0;
	virtual int StopPullRtmpStream(std::string& strUrl) = 0;
	virtual bool SetPullStreamMute(std::string& strUrl, bool bMute) = 0;
	virtual bool UpdatePullVideoRender(HWND hWnd, std::string& strUrl) = 0; // used when switch push/pull stream hwnd.

	// version
	virtual std::string& GetCompileVersion(void) = 0;
	virtual std::string& GetAvCoreVersion(void) = 0;
};

struct IAvLiveCoreSink
{
	virtual ~IAvLiveCoreSink() {}
	virtual int OnNotify(int nType) = 0;
};


API_LIVE_CORE IAvLiveCore* CreateLiveInstance(void);
API_LIVE_CORE void ReleaseLiveInstance(IAvLiveCore*& pAvCore);

#endif // __I_AV_LIVE_CORE_H__
